@@ -238,6 +238,8 @@ class Profile(object):
             data_dict = {k: v for k, v in data_dict.items()
                          if not cls.profile_id_from_key(k.decode()) in profiles_from_db}
 
+            print('1.' + str(user_id) + ': ' + str(data_dict.keys()))
+
         if db_fallback and len(profiles_from_db) == 0:
             cls.set_db_lookup_fail(user_id=user_id)
 
@@ -248,9 +250,12 @@ class Profile(object):
                                          try_db=False) for key, d in data_dict.items()
                      if not d is None]
                     if not profile is None]
+        print('2.' + str(user_id) + ': ' + str([p.profile_id for p in profiles]))
 
         profiles += list(profiles_from_db.values())
 
+        print('3.' + str(user_id) + ': ' + str([p.profile_id for p in profiles]))
+
         if len(profiles) == 0:
             return None
         if len(profiles_from_db) >= cls.fast_clean_threshold:
